
#ifndef _RCALC_CLASS_H
#define _RCALC_CLASS_H
/***********************************************/

#include "repcoder.h"
#include <string>

class RCALC
{
int Handle;

public:
RCALC();
RCALC(int OtherHandle);
RCALC(RCALC& rc);
~RCALC();
bool CopyFrom(RCALC& rc);

int  GetHandle() { return Handle; }
int  GetState();
bool IsValid();
bool IsCompiled();
bool IsExecuted();

void SetStatusWindow(HWND hStatWnd);

bool Compile(const wchar_t* pText);
bool Compile(const char* pText);
bool CompileFile(const wchar_t* FileName, int Format=0);
bool CompileFile(const char* FileName, int Format=0);

std::wstring CompiledText(bool bCRLF=1);
std::string CompiledTextA(bool bCRLF=1);

int InputCount();
int InputType(int number);
int InputTypeNumericScale(int number);
std::wstring InputTypeName(int number);
std::string InputTypeNameA(int number);
std::wstring InputName(int number);
std::string InputNameA(int number);

int OutCount();
int OutType(int number);
int OutTypeTextLen(int number);
int OutTypeNumericScale(int number);
std::wstring OutTypeName(int number);
std::string OutTypeNameA(int number);
std::wstring OutName(int number);
std::string OutNameA(int number);

bool Execute(int nInput, const wchar_t* const* pInputValues);
bool Execute(int nInput, const char* const* pInputValues);
bool Execute(const wchar_t* InputValues, const wchar_t* Separator=0);
bool Execute(const char* InputValues, const char* Separator=0);
bool Execute(int nInput, const std::wstring* pInputValues);
bool Execute(int nInput, const std::string* pInputValues);

bool InputIsNull(int number);
std::wstring InputString(int number);
std::string InputStringA(int number);
double InputDouble(int number);
int InputInt(int number);
__int64 InputNumeric(int number);
__int64 InputTime(int number);

bool OutIsNull(int number);
std::wstring OutString(int number);
std::string OutStringA(int number);
double OutDouble(int number);
int OutInt(int number);
__int64 OutNumeric(int number);
__int64 OutTime(int number);

static int Year(__int64 value) { return rcalc_get_year(value); }
static int Month(__int64 value) { return rcalc_get_month(value); }
static int Day(__int64 value) { return rcalc_get_day(value); }
static int Hour(__int64 value) { return rcalc_get_hour(value); }
static int Minute(__int64 value) { return rcalc_get_minute(value); }
static int Second(__int64 value) { return rcalc_get_second(value); }
static int Millisec(__int64 value) { return rcalc_get_millisec(value); }

static bool LastError();
static void ShowError(HWND hParent=0);
static std::wstring ErrorString();
static std::string ErrorStringA();
};

/***********************************************/
#endif

