
//compile: csc sample.cs repcoder.cs

using System;

class App
{
 public static void ShowLastError()
   {
    if( RCALC.LastError() ) // Check for the last error (in the current thread)
      {
       RCALC.ShowError((IntPtr)0); // Show error in MessageBox
       Console.WriteLine(RCALC.ErrorString() + "\n"); // Print error to Console
      }
   }
//-----------------------------      

 public static void Execute(RCALC rc, string[] Inputs)
   {
    bool ok = rc.Execute(Inputs);
    if( !ok ) ShowLastError();

    // Show INPUT values
    Console.WriteLine("\nINPUT:\n");
    int nIn = rc.InputCount();
    for(int i=1; i<=nIn; i++)
      {
       bool bNull = rc.InputIsNull(i); // Check for null input value

       string name = rc.InputName(i);
       string type_name = rc.InputTypeName(i);

       string value;
       if( bNull ) value = "<NULL>";
       else value = rc.InputString(i); // Get the value as string

       Console.WriteLine(i + "). " + name + " [" + type_name + "]: " + value);
      }
    
    Console.WriteLine("\nOUTPUT:\n");
    int nOut = rc.OutputCount();
    for(int i=1; i<=nOut; i++)
      {
       bool bNull = rc.OutIsNull(i); // Check for null result

       string name = rc.OutName(i);   
       string type_name = rc.OutTypeName(i);

       string result;
       if( bNull ) result = "<NULL>";
       else result = rc.OutString(i); // Get the result as string

       Console.WriteLine(i + "). " + name + " [" + type_name + "]: " + result);
      }   
   }
//-----------------------------

 public static void Main()
   {
    Console.Write("Enter the sample number (1, 2, ..., 18): ");
    int snum = Convert.ToInt32(Console.ReadLine());
    
    if( snum < 1 || snum > 18 )
      {
       Console.WriteLine("The sample number must be an integer from 1 to 18 ...)");
       return;
      }
   
// Init repcoder
    if( !Repcoder.init() ) 
      {
       Console.WriteLine("Repcoder.init() error ...");
       return;
      }

// Create RCALC object
    RCALC rc = new RCALC();
    
// Compile RCALC script file
    bool ok = rc.CompileFile(".\\Samples\\sample_" + ((snum<=9)? "0":"") + snum + ".txt", 0);
    if( !ok )
      {
       RCALC.ShowError((IntPtr)0);
       if( RCALC.LastError() ) Console.WriteLine(RCALC.ErrorString() + "\n");
       
       Repcoder.exit();
       return;
      }
           
// Show compiled text
    string compstr = rc.CompiledText(true);
    if( compstr != String.Empty ) 
      { 
       Console.WriteLine("\n******* Compiled text ***************\n");
       Console.WriteLine(compstr);
       Console.WriteLine("\n*************************************\n");
      }
      
    int nIn = rc.InputCount();
    string[] Inputs = new string[0];
    if( nIn > 0 )
      {
       Inputs = new string[nIn];
       Console.WriteLine("\nEnter " + nIn + " input values:\n");
       for(int i=0; i<nIn; i++)
         {
          string name = rc.InputName(i+1);
          string type_name = rc.InputTypeName(i+1);
          Console.Write((i+1) + "). " + name + " [" + type_name + "]: ");
      
          Inputs[i] = Console.ReadLine();
         }
      }
      
    Execute(rc, Inputs);
    
// Exit repcoder
    Repcoder.exit();
   }
}
