
/*
compile VC++: cl /EHsc sample.cpp rcalc_class.cpp repcoder.c user32.lib
compile BCC32: bcc32 sample.cpp rcalc_class.cpp repcoder.c
*/

#include "rcalc_class.h"
#include <stdio.h>

#include <iostream>
#include <string>
//------------------------

static void _Execute(RCALC& rc, int nInput, const std::string* pInput)
{
// Execute RCALC object with some InputValues
bool ok = rc.Execute(nInput, pInput);
if( !ok )
  {
   // Show error in MessageBox
   RCALC::ShowError();

   // Print also last error (in the current thread) to Console
   if( RCALC::LastError() ) std::cout<< RCALC::ErrorStringA() << "\n\n";
  }

// Show INPUT values
std::cout << "\nINPUT:\n\n";
int nIn = rc.InputCount();
for(int i=1; i<=nIn; i++)
  {
   bool bNull = rc.InputIsNull(i); // Check for null input value

   std::string name = rc.InputNameA(i);
   std::string type_name = rc.InputTypeNameA(i);

   std::string value;
   if( bNull ) value = "<NULL>";
   else value = rc.InputStringA(i); // Get the value as std::string (ansi version)

   std::cout<< i << "). " << name << " [" << type_name << "]: " << value << "\n";
  }

// Show OUTPUT values
std::cout<<"\nOUTPUT:\n\n";
int nOut = rc.OutCount();
for(int i=1; i<=nOut; i++)
  {
   bool bNull = rc.OutIsNull(i); // Check for null result

   std::string name = rc.OutNameA(i);
   std::string type_name = rc.OutTypeNameA(i);

   std::string result;
   if( bNull ) result = "<NULL>";
   else result = rc.OutStringA(i); // Get the result as std::string (ansi version)

   std::cout<< i << "). " << name << " [" << type_name << "]: " << result << "\n";
  }
}
//------------------------

int main()
{
std::cout << "Enter the sample number (1, 2, ..., 18): ";

int testnum;
std::cin >> testnum;
if( testnum < 1 || testnum > 18 )
  {
   std::cout << "The sample number must be an integer from 1 to 18 ...\n";
   return 0;
  }

std::cin.ignore();

// Load repcoder.dll
if( !repcoder_load() ) return 0;

// Init repcoder
if( !repc_init() ) { repcoder_free(); return 0; }

// Create RCALC object
RCALC rc;

char fname[100];
wsprintfA(fname, ".\\Samples\\sample_%02d.txt", testnum);

// Compile RCALC script file
bool ok = rc.CompileFile(fname);
if( !ok )
  {
   // Show error in MessageBox
   RCALC::ShowError();
   
   // Print also last error (in the current thread) to Console
   if( RCALC::LastError() ) std::cout<< RCALC::ErrorStringA() << "\n";

   repc_exit();
   repcoder_free();
   return 0;
  }

// Show compiled text
std::cout << "\n************* Compiled text *************\n\n";
std::cout << rc.CompiledTextA();
std::cout << "\n\n*****************************************\n\n";

std::string* pInput = 0;
int nIn = rc.InputCount();
if( nIn > 0 )
  {
   pInput = new std::string[nIn];
   if( !pInput ) { std::cout << "new Error !!!\n"; repc_exit(); repcoder_free(); return 0; }

   std::cout << "\nEnter " << nIn << " input values:\n\n";
   for(int i=0; i<nIn; i++)
     {
      std::string name = rc.InputNameA(i+1);
      std::string type_name = rc.InputTypeNameA(i+1);
      std::cout << i+1 << "). " << name << " [" << type_name << "]: ";

      std::getline(std::cin, pInput[i]);
     }
  }

// Execute the script (with the input values)
_Execute(rc, nIn, pInput);
if( pInput ) delete[] pInput;

// Exit repcoder
repc_exit();

// Free repcoder.dll
repcoder_free();
return 0;
}

