/*
compile VC++: cl test.c repcoder.c user32.lib
compile BCC32: bcc32 test.c repcoder.c
*/

#include "repcoder.h"
#include <stdio.h>
//------------------------

// Text of an algorithm
const char* AlgTxt = 
"INPUT {"
"FLOAT x;"
"FLOAT y;"
"}"
"FLOAT z = x + y;"
"OUTPUT {"
"FLOAT Out1 = z*z;"
"FLOAT Out2 = sqrt(x + y);"
"}";
//------------------------

int main(void)
{
int h, nOut;
BOOL ok;
double Out1, Out2;

// Load repcoder.dll
if( !repcoder_load() ) return 0;

// Init repcoder
if( !repc_init() ) { repcoder_free(); return 0; }

// Alloc RCALC handle
h = rcalc_alloc_handle();
if( !h ) { repc_exit(); repcoder_free(); return 0; }

// Compile RCALC handle (ANSI version: _a)
ok = rcalc_compile_a(h, AlgTxt);
if( !ok )
  {
   rcalc_show_error(0); // Show error in a MessageBox
   rcalc_free_handle(h); repc_exit(); repcoder_free();
   return 0;
  }

// Show compiled text in the Console
printf("\n******* Compiled text ***************\n\n");
printf(rcalc_get_compiled_text_a(h, 1));
// or UNICODE:
// wprintf(rcalc_get_compiled_text(h, 1));
printf("\n\n******* End of compiled text ********\n\n");

// Get and print the number of output values
nOut = rcalc_get_output_count(h);
printf("nOut = %d\n", nOut);

// Execute with some input values: x = 3.14159, y = 2.71
ok = rcalc_execute2_a(h, "3.14159###2.71", 0);
if( !ok )
  {
   rcalc_show_error(0);
   rcalc_free_handle(h); repc_exit(); repcoder_free();
   return 0;
  }

// Print the results (UNICODE version)
wprintf(L"Out1 = %s\n", rcalc_get_output_string(h, 1));
wprintf(L"Out2 = %s\n\n", rcalc_get_output_string(h, 2));

// Get the results to host variables
Out1 = rcalc_get_output_double(h, 1);
Out2 = rcalc_get_output_double(h, 2);
printf("Out1 = %lf, Out2 = %lf\n", Out1, Out2);

// Free RCALC handle (not necessary, repc_exit() can also free it)
rcalc_free_handle(h);

// Exit repcoder
repc_exit();

// Free repcoder.dll
repcoder_free();
return 0;
}

