/*
compile VC++: cl /EHsc test.cpp rcalc_class.cpp repcoder.c user32.lib
compile BCC32: bcc32 rcalc_class.cpp test.cpp repcoder.c
*/

#include "rcalc_class.h"
#include <iostream>
//------------------------

// Text of an algorithm
const char* AlgTxt =
"INPUT {"
"FLOAT x;"
"FLOAT y;"
"}"
"FLOAT z = x + y;"
"OUTPUT {"
"FLOAT Out1 = z*z;"
"FLOAT Out2 = sqrt(x + y);"
"}";
//------------------------

int main(void)
{
// Load repcoder.dll
if( !repcoder_load() ) return 0;

// Init repcoder
if( !repc_init() ) { repcoder_free(); return 0; }

// Create RCALC object
RCALC rc;

// Compile RCALC handle (ANSI version: _a)
bool ok = rc.Compile(AlgTxt);
if( !ok )
  {
   RCALC::ShowError(); // Show error in a MessageBox
   repc_exit();
   repcoder_free();
   return 0;
  }

// Show compiled text in the Console
std::cout<< "\n******* Compiled text ***************\n\n";
std::cout<< rc.CompiledTextA().c_str();
// or UNICODE:
// std::wcout<< rc.CompiledText.c_str();
std::cout<< "\n\n******* End of compiled text ********\n\n";

// Get and print the number of output values
int nOut = rc.OutCount();
std::cout<< "nOut = " << nOut << "\n";

// Execute with some input values: x = 3.14159, y = 2.71
ok = rc.Execute("3.14159###2.71");
if( !ok )
  {
   RCALC::ShowError();
   repc_exit(); repcoder_free();
   return 0;
  }

// Print the results (UNICODE version)
std::wcout << L"Out1 = " << rc.OutString(1) << L"\n";
std::wcout << L"Out2 = " << rc.OutString(2) << L"\n\n";

// Get the results to host variables
double Out1 = rc.OutDouble(1);
double Out2 = rc.OutDouble(2);
std::cout << "Out1 = " << Out1 << ", Out2 = " << Out2 << "\n";

// Exit repcoder
repc_exit();

// Free repcoder.dll
repcoder_free();
return 0;
}

