
/*
compile VC++: cl test2.c repcoder.c user32.lib
compile BCC32: bcc32 rcalc_test1.c repcoder.c
*/

#include "repcoder.h"
#include <stdio.h>
//------------------------

static void _PrintError(void)
{
int n;
wchar_t* buf;
BOOL ret;

n = rcalc_get_error_text_len(); // last error text length (in the current thread)
if( !n ) return;

buf = (wchar_t*)malloc((n+1)*sizeof(wchar_t));
if( !buf ) return;

ret = rcalc_copy_error_text(buf, n+1); // copy last error text to buffer (in the current thread)
if( !ret ) { free(buf); return; }

if( buf[0] ) wprintf(L"%s\n", buf);
free(buf);
}
//------------------------

static void _Execute(int h, const wchar_t* InputValues, const wchar_t* Sep)
{
BOOL ok;
int nOut, i;

if( !h ) return;

// Execute compiled handle with some InputValues
ok = rcalc_execute2(h, InputValues, Sep);
if( !ok )
  {
   rcalc_show_error(0); // Show error in MessageBox
   _PrintError(); // Print error to Console
  }

nOut = rcalc_get_output_count(h);
for(i=1; i<=nOut; i++)
  {
   const wchar_t* pType;
   int textlen;
   wchar_t type_name[64] = L"";
   const wchar_t* pName;
   const wchar_t* pResult;
   BOOL bNull;

   pType = rcalc_get_output_type_name(h, i);
   textlen = rcalc_get_output_type_textlen(h, i);

   if( pType && textlen ) wsprintfW(type_name, L"%s(%d)", pType, textlen);
   else if( pType ) wcscpy(type_name, pType);

   pName = rcalc_get_output_name(h, i);
   pResult = rcalc_get_output_string(h, i); // Get the result as text

   bNull = rcalc_isnull_output(h, i); // Check for null result

   if( bNull ) wprintf(L"%d). %s [%s]: <NULL>\n", i, pName, type_name);
   else wprintf(L"%d). %s [%s]: %s\n", i, pName, type_name, pResult);
  }
}
//------------------------

int main(void)
{
int h, h2, nOut, i;
BOOL ok;
__int64 tm;

// Load repcoder.dll
if( !repcoder_load() ) return 0;

// Init repcoder
if( !repc_init() ) { repcoder_free(); return 0; }

// Alloc RCALC handle
h = rcalc_alloc_handle();
if( !h ) { repc_exit(); repcoder_free(); return 0; }

// Compile RCALC script file
ok = rcalc_compile_file(h, L".\\Samples\\test2.txt", 0);
if( !ok )
  {
   rcalc_show_error(0); // Show error in MessageBox
   _PrintError(); // Print error to Console

   rcalc_free_handle(h);
   repc_exit();
   repcoder_free();
   return 0;
  }

// Show compiled text
MessageBoxW(0, rcalc_get_compiled_text(h, 1), L"Compiled text", MB_OK);

// Get and print the number of output values
nOut = rcalc_get_output_count(h);
wprintf(L"nOut = %d\n", nOut);

// Get and print the output names and their types
for(i=1; i<=nOut; i++)
  {
   int textlen;
   const wchar_t* pType;
   wchar_t type_name[64] = L"";
   const wchar_t* pName;

   textlen = rcalc_get_output_type_textlen(h, i);
   pType = rcalc_get_output_type_name(h, i);

   if( pType && textlen ) wsprintfW(type_name, L"%s(%d)", pType, textlen);
   else if( pType ) wcscpy(type_name, pType);

   pName = rcalc_get_output_name(h, i);
   wprintf(L"%d). %s [%s]\n", i, pName, type_name);
  }

wprintf(L"\nResults:\n\n");

// Execute the script 6 times with different sets of input parameters
_Execute(h, L"-12.3456###-5.67", 0); wprintf(L"\n"); // standard separator string: "###"
h2 = rcalc_copy_handle(h); // make a copy of h (will be used at the end)

_Execute(h, L"0.23|8.43", L"|"); wprintf(L"\n"); // custom separator string: "|"
_Execute(h, L"45 @ -34.67", L" @ "); wprintf(L"\n"); // custom separator string: " @ "
_Execute(h, L"###457.93", 0); wprintf(L"\n"); // NULL value passed as parameter 1
_Execute(h, L"786###", 0); wprintf(L"\n"); // NULL value passed as parameter 2
_Execute(h, 0, 0); wprintf(L"\n"); // NULL values passed for all input parameters

// Show some results for rc2 (copy of rc after the first execute)
wprintf(L"\n");
wprintf(L"Out1 (numeric) = %I64d\n", rcalc_get_output_numeric(h2, 1)); // convert to long (64-bit integer)
wprintf(L"Out1 (double) = %lf\n", rcalc_get_output_double(h2, 1)); // convert to double
wprintf(L"Out1 (int) = %d\n", rcalc_get_output_int(h2, 1)); // convert to int
wprintf(L"Out1 (string) = %s\n", rcalc_get_output_string(h2, 1)); // show as string

wprintf(L"\n");
wprintf(L"Out2 (numeric) = %I64d\n", rcalc_get_output_numeric(h2, 2)); // convert to long (64-bit integer)
wprintf(L"Out2 (double) = %lf\n", rcalc_get_output_double(h2, 2)); // convert to double
wprintf(L"Out2 (int) = %d\n", rcalc_get_output_int(h2, 2)); // convert to int
wprintf(L"Out2 (string) = %s\n", rcalc_get_output_string(h2, 2)); // show as string

wprintf(L"\n");
wprintf(L"Out3 (numeric) = %I64d\n", rcalc_get_output_numeric(h2, 3)); // convert to long (64-bit integer)
wprintf(L"Out3 (double) = %lf\n", rcalc_get_output_double(h2, 3)); // convert to double
wprintf(L"Out3 (int) = %d\n", rcalc_get_output_int(h2, 3)); // convert to int
wprintf(L"Out3 (string) = %s\n", rcalc_get_output_string(h2, 3)); // show as string

tm = rcalc_get_output_time(h2, 8); // date, time and timestamp are returned as long (64-bit)
wprintf(L"\n");
wprintf(L"Out8 (date) = %04d-%02d-%02d\n", rcalc_get_year(tm), rcalc_get_month(tm), rcalc_get_day(tm)); // extract date parameters from this long result
wprintf(L"Out8 (string) = %s\n", rcalc_get_output_string(h2, 8));

// Free RCALC handle (not necessary, repc_exit() can also free it)
rcalc_free_handle(h);
rcalc_free_handle(h2);

// Exit repcoder
repc_exit();

// Free repcoder.dll
repcoder_free();
return 0;
}

