
/*
compile VC++: cl /EHsc thrtest2.cpp rcalc_class.cpp repcoder.c user32.lib
compile BCC32: bcc32 -tWM thrtest2.cpp rcalc_class.cpp repcoder.c
*/

#include "repcoder.h"
#include "rcalc_class.h"
#include <process.h>
#include <iostream>
//------------------------

static const int NUM_THREADS = 10; // number of threads
static const int N_LOOP = 50000; // number of WHILE loops

// Input structure for a thread
struct THR_STRUCT
{
int Nr;
RCALC* pCalc;
volatile int bEnd;
};

// Thread procedure
static void _ThrProc(void* ptr)
{
if( !ptr ) return;
THR_STRUCT* pts = (THR_STRUCT*)ptr;

// Make a copy of the primary (compiled) object
RCALC rc( *(pts->pCalc) );
if( !rc.IsValid() ) { RCALC::ShowError(); pts->bEnd = 1; return; }

// Set the 2 input values for the RCALC script
char InputValues[100];
wsprintfA(InputValues, "%d###%d", pts->Nr, N_LOOP);

// Execute the RCALC code
rc.Execute(InputValues);

// Show RCALC error (if any)
RCALC::ShowError();

// Mark the volatile flag that the thread has finished
// for the join code in the main() function
pts->bEnd = 1;
}
//------------------------

int main()
{
// Load and init repcoder.dll
if( !repcoder_load() ) return 0;
if( !repc_init() ) { repcoder_free(); return 0; }

// Create the primary RCALC object in the main thread
RCALC rc;
if( !rc.IsValid() ) { repc_exit(); repcoder_free(); return 0; }

// Compile the object (only once !!!)
bool ok = rc.CompileFile(".\\Samples\\threads.txt");
if( !ok )
  {
   RCALC::ShowError();

   repc_exit();
   repcoder_free();
   return 0;
  }

std::cout << "\nStarting 11 threads.\nPlease wait ...\n";

// Allocate input structures for child threads
int nThr = NUM_THREADS;
THR_STRUCT* params = new THR_STRUCT[nThr];
if( !params )
  {
   repc_exit();
   repcoder_free();
   return 0;
  }

// Start the child threads
for(int i=0; i<nThr; i++)
  {
   params[i].Nr = i+1;
   params[i].pCalc = &rc;
   params[i].bEnd = 0;
   _beginthread(_ThrProc, 0, params+i);
  }

// Execute the RCALC code also in the main thread:
// ... make also a copy of the primary (compiled) object
RCALC rc2(rc);
// ... set the 2 input values for the RCALC script
char InputValues[100];
wsprintfA(InputValues, "%d###%d", nThr+1, N_LOOP);
// Execute the RCALC code
rc2.Execute(InputValues);

// Join the threads
while(1)
  {
   int bStop = 1;
   for(int i=0; i<nThr; i++)
     {
      if( params[i].bEnd == 0 ) { bStop = 0; break; }
     }
   if( bStop ) break;
   Sleep(100);
  }

std::cout << "\nThe result files were created in the current dir:\n"
"res_1.txt, res_2.txt, ..., res_11.txt\n";

// Delete the input structures
delete[] params;

// Show RCALC error (if any)
RCALC::ShowError();

// Exit and free repcoder.dll
repc_exit();
repcoder_free();
return 0;
}

