
//compile: dcc32 -CC test.pas repcoder.pas

program test;

uses repcoder;

var 
rc: RCALC;
bOk: Boolean;
nOut: Integer;
Out1: Double;
Out2: Double;
AlgTxt: AnsiString;

begin

// Init repcoder
if repc_init = False then 
begin 
  WriteLn('repc_init() error ...'); 
  Halt(1);
end;

// Alloc RCALC handle
rc := RCALC.Create;

// Text of an algorithm
AlgTxt := 
'INPUT {' +
'FLOAT x;' +
'FLOAT y;' +
'}' +
'FLOAT z = x + y;' +
'OUTPUT {' +
'FLOAT Out1 = z*z;' +
'FLOAT Out2 = sqrt(x + y);' +
'}';

// Compile RCALC handle
bOk := rc.Compile(AlgTxt);
if bOk = False then
begin
  RCALC_ShowError(0); // Show error in a MessageBox
  repc_exit;
  Halt(1);
end;

// Show compiled text in the Console
WriteLn(#13#10 + '******* Compiled text ***************' + #13#10);
WriteLn(rc.CompiledText(True));
WriteLn(#13#10 + '******* End of compiled text ********' + #13#10);

// Get and print the number of output values
nOut := rc.OutputCount;
WriteLn('nOut = ', nOut);

// Execute with some input values: x = 3.14159, y = 2.71
bOk := rc.Execute('3.14159###2.71');
if bOk = False then
begin
  RCALC_ShowError(0);
  repc_exit;
  Halt(1);
end;

// Print the results
WriteLn('Out1 = ', rc.OutString(1));
WriteLn('Out2 = ', rc.OutString(2) + #13#10);

// Get the results to host variables
Out1 := rc.OutDouble(1);
Out2 := rc.OutDouble(2);
WriteLn('Out1 = ', Out1, ', Out2 = ', Out2);

// Exit repcoder
repc_exit;

end.
