
//compile: dcc32 -CC test_handle.pas repcoder.pas

program test;

uses sysutils, repcoder;

var 
h: Integer;
bOk: Boolean;
nOut: Integer;
Out1: Double;
Out2: Double;
AlgTxt: AnsiString;

begin

// Init repcoder
if repc_init = False then 
begin 
  WriteLn('repc_init() error ...'); 
  Halt(1);
end;

// Alloc RCALC handle
h := rcalc_alloc_handle;
if h = 0 then
begin
  repc_exit;
  Halt(1);
end;

// Text of an algorithm
AlgTxt := 
'INPUT {' +
'FLOAT x;' +
'FLOAT y;' +
'}' +
'FLOAT z = x + y;' +
'OUTPUT {' +
'FLOAT Out1 = z*z;' +
'FLOAT Out2 = sqrt(x + y);' +
'}';

// Compile RCALC handle (ANSI version: _a)
bOk := rcalc_compile_a(h, AlgTxt);
if bOk = False then
begin
  rcalc_show_error(0); // Show error in a MessageBox
  rcalc_free_handle(h);
  repc_exit;
  Halt(1);
end;

// Show compiled text in the Console (ANSI version): _a
WriteLn(#13#10 + '******* Compiled string ***************' + #13#10);
WriteLn(rcalc_get_compiled_text_a(h, True));
WriteLn(#13#10 + '******* End of compiled string ********' + #13#10);

// Get and print the number of output values
nOut := rcalc_get_output_count(h);
WriteLn('nOut = ', nOut);

// Execute with some input values: x = 3.14159, y = 2.71
bOk := rcalc_execute2_a(h, '3.14159|2.71', '|');
if bOk = False then
begin
  rcalc_show_error(0);
  rcalc_free_handle(h);
  repc_exit;
  Halt(1);
end;

// Print the results (ANSI version): _a
WriteLn('Out1 = ', rcalc_get_output_string_a(h, 1));
WriteLn('Out2 = ', rcalc_get_output_string_a(h, 2) + #13#10);

// Get the results to host variables
Out1 := rcalc_get_output_double(h, 1);
Out2 := rcalc_get_output_double(h, 2);
WriteLn('Out1 = ', Out1, ', Out2 = ', Out2);

// Free RCALC handle (not necessary, repc_exit() can also free it)
rcalc_free_handle(h);

// Exit repcoder
repc_exit;

end.
