
//compile: javac -cp jna.jar Repcoder.java Test.java
//run: java -cp jna.jar; Test
    
public class Test
{
public static void main(String[] args)
  {
// Init repcoder
   if( !Repcoder.init() )
     {
      System.out.println("Repcoder.init() error ...");
      return;
     }

// Create RCALC object
   RCALC rc = new RCALC();

   String AlgTxt =
   "INPUT {" +
   "FLOAT x;" +
   "FLOAT y;" +
   "}" +
   "FLOAT z = x + y;" +
   "OUTPUT {" +
   "FLOAT Out1 = z*z;" +
   "FLOAT Out2 = sqrt(x + y);" +
   "}";

// Compile RCALC object
   boolean ok = rc.Compile(AlgTxt);
   if( !ok )
     {
      RCALC.ShowError(0);
      Repcoder.exit();
      return;
     }

// Show compiled text in the Console
   String compstr = rc.CompiledText(true);
   if( !compstr.isEmpty() )
     {
      System.out.println("\n******* Compiled text ***************\n");
      System.out.println(compstr);
      System.out.println("\n******* End of compiled text ********\n");
     }

// Get and print the number of output values
   int nOut = rc.OutputCount();
   System.out.println("nOut = " + nOut);

// Execute with some input values: x = 3.14159, y = 2.71
   ok = rc.Execute("3.14159###2.71");
   if( !ok )
     {
      RCALC.ShowError(0);
      Repcoder.exit();
      return;
     }

// Print the results
   System.out.println("Out1 = " + rc.OutString(1));
   System.out.println("Out2 = " + rc.OutString(2) + "\n");

// Get the results to host variables
   double Out1 = rc.OutDouble(1);
   double Out2 = rc.OutDouble(2);
   System.out.println("Out1 = " + Out1 + ", Out2 = " + Out2);
   
// Call Free() to clear resources !!!
   rc.Free();

// Exit repcoder
   Repcoder.exit();
  }
}
